@@ -1,4 +1,4 @@
-a <- c(2, 1, 0, 2, 0, 1, 1, 1)
+a = c(2, 1, 0, 2, 0, 1, 1, 1)
 b <- c(2, 1, 1, 1, 1, 0, 1, 1)
 
 test_that("cosine similarity test", {
